==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebTimeFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseDateTimeFilteringOperandDescriptionMetadata } from "./WebBaseDateTimeFilteringOperandDescriptionMetadata";
import { WebTimeFilteringOperandDescription } from "./WebTimeFilteringOperandDescription";
/**
 * @hidden
 */
export let WebTimeFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTimeFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebTimeFilteringOperandDescriptionMetadata.a == null) {
                WebTimeFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTimeFilteringOperandDescriptionMetadata.c(WebTimeFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebTimeFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebTimeFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseDateTimeFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TimeFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebTimeFilteringOperandDescriptionMetadata.b(a);
            a.ad("WebTimeFilteringOperand", () => new WebTimeFilteringOperandDescription());
            a.ac("WebTimeFilteringOperand", WebTimeFilteringOperandDescriptionMetadata.a);
        }
    }
    WebTimeFilteringOperandDescriptionMetadata.$t = markType(WebTimeFilteringOperandDescriptionMetadata, 'WebTimeFilteringOperandDescriptionMetadata');
    WebTimeFilteringOperandDescriptionMetadata.a = null;
    return WebTimeFilteringOperandDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebTimeFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseDateTimeFilteringOperandDescriptionMetadata } from "./WebBaseDateTimeFilteringOperandDescriptionMetadata";
import { WebTimeFilteringOperandDescription } from "./WebTimeFilteringOperandDescription";
/**
 * @hidden
 */
export let WebTimeFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTimeFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebTimeFilteringOperandDescriptionMetadata.a == null) {
                WebTimeFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTimeFilteringOperandDescriptionMetadata.c(WebTimeFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebTimeFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebTimeFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseDateTimeFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:TimeFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebTimeFilteringOperandDescriptionMetadata.b(a);
            a.ae("WebTimeFilteringOperand", () => new WebTimeFilteringOperandDescription());
            a.ad("WebTimeFilteringOperand", WebTimeFilteringOperandDescriptionMetadata.a);
        }
    }
    WebTimeFilteringOperandDescriptionMetadata.$t = markType(WebTimeFilteringOperandDescriptionMetadata, 'WebTimeFilteringOperandDescriptionMetadata');
    WebTimeFilteringOperandDescriptionMetadata.a = null;
    return WebTimeFilteringOperandDescriptionMetadata;
})();
